@@ -19,6 +19,7 @@ import pytest ; pytest
 
 # Standard library imports
 from mock import patch
+from collections import OrderedDict
 
 # External imports
 import bs4
@@ -95,6 +96,10 @@ class Test_components(object):
         assert isinstance(divs, dict)
         assert all(isinstance(x, string_types) for x in divs.keys())
 
+        _, divs = bes.components(OrderedDict([("Plot 1", plot1), ("Plot 2", plot2)]))
+        assert isinstance(divs, OrderedDict)
+        assert all(isinstance(x, string_types) for x in divs.keys())
+
     @patch('bokeh.embed.util.make_globally_unique_id', new_callable=lambda: stable_id)
     def test_plot_dict_returned_when_wrap_plot_info_is_false(self, mock_make_id):
         doc = Document()
