@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2017, Anaconda, Inc. All rights reserved.
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
 #
 # Powered by the Bokeh Development Team.
 #
@@ -17,8 +17,6 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import logging
 log = logging.getLogger(__name__)
 
-from bokeh.util.api import general, dev ; general, dev
-
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
@@ -35,16 +33,21 @@ from .state import curstate
 # Globals and constants
 #-----------------------------------------------------------------------------
 
+__all__ = (
+    'output_file',
+    'output_notebook',
+    'reset_output',
+)
+
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
 
-@general((1,0,0))
 def output_file(filename, title="Bokeh Plot", mode="cdn", root_dir=None):
     '''Configure the default output state to generate output saved
     to a file when :func:`show` is called.
 
-    Does not change the current Document from curdoc(). File and notebook
+    Does not change the current ``Document`` from ``curdoc()``. File and notebook
     output may be active at the same time, so e.g., this does not clear the
     effects of ``output_notebook()``.
 
@@ -80,7 +83,6 @@ def output_file(filename, title="Bokeh Plot", mode="cdn", root_dir=None):
         root_dir=root_dir
     )
 
-@general((1,0,0))
 def output_notebook(resources=None, verbose=False, hide_banner=False, load_timeout=5000, notebook_type='jupyter'):
     ''' Configure the default output state to generate output in notebook cells
     when :func:`show` is called. Note that, :func:`show` may be called multiple
@@ -115,7 +117,6 @@ def output_notebook(resources=None, verbose=False, hide_banner=False, load_timeo
     curstate().output_notebook(notebook_type)
     run_notebook_hook(notebook_type, 'load', resources, verbose, hide_banner, load_timeout)
 
-@general((1,0,0))
 def reset_output(state=None):
     ''' Clear the default state of all output modes.
 
