@@ -10,11 +10,13 @@ The full list of glyphs built into Bokeh is given below:
 * :class:`~bokeh.models.glyphs.Bezier`
 * :class:`~bokeh.models.glyphs.Ellipse`
 * :class:`~bokeh.models.glyphs.HBar`
+* :class:`~bokeh.models.glyphs.HexTile`
 * :class:`~bokeh.models.glyphs.Image`
 * :class:`~bokeh.models.glyphs.ImageRGBA`
 * :class:`~bokeh.models.glyphs.ImageURL`
 * :class:`~bokeh.models.glyphs.Line`
 * :class:`~bokeh.models.glyphs.MultiLine`
+* :class:`~bokeh.models.glyphs.MultiPolygons`
 * :class:`~bokeh.models.glyphs.Oval`
 * :class:`~bokeh.models.glyphs.Patch`
 * :class:`~bokeh.models.glyphs.Patches`
@@ -23,6 +25,7 @@ The full list of glyphs built into Bokeh is given below:
 * :class:`~bokeh.models.glyphs.Ray`
 * :class:`~bokeh.models.glyphs.Rect`
 * :class:`~bokeh.models.glyphs.Segment`
+* :class:`~bokeh.models.glyphs.Step`
 * :class:`~bokeh.models.glyphs.Text`
 * :class:`~bokeh.models.glyphs.VBar`
 * :class:`~bokeh.models.glyphs.Wedge`
@@ -36,11 +39,11 @@ All these glyphs share a minimal common interface through their base class
 '''
 from __future__ import absolute_import
 
-from ..core.enums import Anchor, Direction
+from ..core.enums import Anchor, Direction, StepMode
 from ..core.has_props import abstract
-from ..core.properties import (AngleSpec, Bool, DistanceSpec, Enum, Float,
-                               Include, Instance, Int, NumberSpec, StringSpec)
-from ..core.property_mixins import FillProps, LineProps, TextProps
+from ..core.properties import (AngleSpec, Bool, DistanceSpec, Enum, Float, String,
+                               Include, Instance, Int, NumberSpec, Override, StringSpec)
+from ..core.property_mixins import FillProps, LineProps, ScalarFillProps, ScalarLineProps, TextProps
 from ..model import Model
 
 from .mappers import ColorMapper, LinearColorMapper
@@ -304,6 +307,59 @@ class HBar(Glyph):
     The %s values for the horizontal bars.
     """)
 
+class HexTile(Glyph):
+    ''' Render horizontal tiles on a regular hexagonal grid.
+
+    '''
+
+    __example__ = "examples/reference/models/HexTile.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('q', 'r')
+
+    size = Float(1.0, help="""
+    The radius (in data space units) of the hex tiling.
+
+    The radius is always measured along the cartesian y-axis for "pointy_top"
+    orientation, and along the cartesian x-axis for "flat_top" orientation. If
+    the aspect ratio of the underlying cartesian system is not 1-1, then the
+    tiles may be "squished" in one direction. To ensure that the tiles are
+    always regular hexagons, consider setting the ``match_aspect`` property of
+    the plot to True.
+    """)
+
+    aspect_scale = Float(1.0, help="""
+
+    """)
+
+    r = NumberSpec(help="""
+    The "row" axial coordinates of the tile centers.
+    """)
+
+    q = NumberSpec(help="""
+    The "column" axial coordinates of the tile centers.
+    """)
+
+    scale = NumberSpec(1.0, help="""
+    A scale factor for individual tiles.
+    """)
+
+    orientation = String("pointytop", help="""
+
+    """)
+
+    line_props = Include(LineProps, use_prefix=False, help="""
+    The %s values for the horizontal bars.
+    """)
+
+    line_color = Override(default=None)
+
+    fill_props = Include(FillProps, use_prefix=False, help="""
+    The %s values for the horizontal bars.
+    """)
+
+
 class Image(XYGlyph):
     ''' Render images given as scalar data together with a color mapper.
 
@@ -332,7 +388,7 @@ class Image(XYGlyph):
 
     # a canonical order for positional args that can be used for any
     # functions derived from this class
-    _args = ('image', 'x', 'y', 'dw', 'dh', 'dilate')
+    _args = ('image', 'x', 'y', 'dw', 'dh', 'global_alpha', 'dilate')
 
     # a hook to specify any additional kwargs handled by an initializer
     _extra_kws = {
@@ -370,6 +426,11 @@ class Image(XYGlyph):
         That number is fixed by the image itself.
     """)
 
+    global_alpha = Float(1.0, help="""
+    An overall opacity that each image is rendered with (in addition
+    to any alpha values applied explicitly in a color mapper).
+    """)
+
     dilate = Bool(False, help="""
     Whether to always round fractional pixel locations in such a way
     as to make the images bigger.
@@ -396,7 +457,7 @@ class ImageRGBA(XYGlyph):
 
     # a canonical order for positional args that can be used for any
     # functions derived from this class
-    _args = ('image', 'x', 'y', 'dw', 'dh', 'dilate')
+    _args = ('image', 'x', 'y', 'dw', 'dh', 'global_alpha', 'dilate')
 
     image = NumberSpec(help="""
     The arrays of RGBA data for the images.
@@ -426,6 +487,11 @@ class ImageRGBA(XYGlyph):
         That number is fixed by the image itself.
     """)
 
+    global_alpha = Float(1.0, help="""
+    An overall opacity that each image is rendered with (in addition
+    to any inherent alpha values in the image itself).
+    """)
+
     dilate = Bool(False, help="""
     Whether to always round fractional pixel locations in such a way
     as to make the images bigger.
@@ -448,8 +514,7 @@ class ImageURL(XYGlyph):
     # functions derived from this class
     _args = ('url', 'x', 'y', 'w', 'h', 'angle', 'global_alpha', 'dilate')
 
-    # TODO (bev) Why is this a NumberSpec??
-    url = NumberSpec(accept_datetime=False, help="""
+    url = StringSpec(default=None, help="""
     The URLs to retrieve images from.
 
     .. note::
@@ -466,7 +531,7 @@ class ImageURL(XYGlyph):
     """)
 
     w = DistanceSpec(default=None, help="""
-    The height of the plot region that the image will occupy in data space.
+    The width of the plot region that the image will occupy in data space.
 
     The default value is ``None``, in which case the image will be displayed
     at its actual image size (regardless of the units specified here).
@@ -532,7 +597,7 @@ class Line(XYGlyph):
     The y-coordinates for the points of the line.
     """)
 
-    line_props = Include(LineProps, use_prefix=False, help="""
+    line_props = Include(ScalarLineProps, use_prefix=False, help="""
     The %s values for the line.
     """)
 
@@ -562,6 +627,46 @@ class MultiLine(Glyph):
     The %s values for the lines.
     """)
 
+class MultiPolygons(Glyph):
+    ''' Render several MultiPolygon.
+
+    Modeled on geoJSON - the data for the ``MultiPolygons`` glyph is
+    different in that the vector of values is not a vector of scalars.
+    Rather, it is a "list of lists of lists of lists".
+    '''
+
+    __example__ = "examples/reference/models/MultiPolygons.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('xs', 'ys')
+
+    xs = NumberSpec(help="""
+    The x-coordinates for all the patches, given as a nested list.
+
+    .. note::
+        Each item in ``MultiPolygons`` represents one MultiPolygon and each
+        MultiPolygon is comprised of ``n`` Polygons. Each Polygon is made of
+        one exterior ring optionally followed by ``m`` interior rings (holes).
+    """)
+
+    ys = NumberSpec(help="""
+    The y-coordinates for all the patches, given as a "list of lists".
+
+    .. note::
+        Each item in ``MultiPolygons`` represents one MultiPolygon and each
+        MultiPolygon is comprised of ``n`` Polygons. Each Polygon is made of
+        one exterior ring optionally followed by ``m`` interior rings (holes).
+    """)
+
+    line_props = Include(LineProps, use_prefix=False, help="""
+    The %s values for the multipolygons.
+    """)
+
+    fill_props = Include(FillProps, use_prefix=False, help="""
+    The %s values for the multipolygons.
+    """)
+
 class Oval(XYGlyph):
     u''' Render ovals.
 
@@ -637,11 +742,11 @@ class Patch(XYGlyph):
         values in the sequence.
     """)
 
-    line_props = Include(LineProps, use_prefix=False, help="""
+    line_props = Include(ScalarLineProps, use_prefix=False, help="""
     The %s values for the patch.
     """)
 
-    fill_props = Include(FillProps, use_prefix=False, help="""
+    fill_props = Include(ScalarFillProps, use_prefix=False, help="""
     The %s values for the patch.
     """)
 
@@ -870,6 +975,44 @@ class Segment(Glyph):
     The %s values for the segments.
     """)
 
+class Step(XYGlyph):
+    ''' Render step lines.
+
+    Step levels can be draw before, after, or centered on each point, according
+    to the value of the ``mode`` property.
+
+    The x-coordinates are assumed to be (and must be) sorted in ascending order
+    for steps to be properly rendered.
+
+    '''
+
+    __example__ = "examples/reference/models/Step.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y')
+
+    x = NumberSpec(help="""
+    The x-coordinates for the steps.
+    """)
+
+    y = NumberSpec(help="""
+    The y-coordinates for the steps.
+    """)
+
+    line_props = Include(LineProps, use_prefix=False, help="""
+    The %s values for the steps.
+    """)
+
+    mode = Enum(StepMode, default="before", help="""
+    Where the step "level" should be drawn in relation to the x and y
+    coordinates. The parameter can assume one of three values:
+
+    * ``before``: (default) Draw step levels before each x-coordinate (no step before the first point)
+    * ``after``:  Draw step levels after each x-coordinate (no step after the last point)
+    * ``center``: Draw step levels centered on each x-coordinate
+    """)
+
 class Text(XYGlyph):
     ''' Render text.
 
@@ -994,9 +1137,10 @@ class Wedge(XYGlyph):
     """)
 
 # XXX: allow `from bokeh.models.glyphs import *`
-from .markers import (Asterisk, Circle, CircleCross, CircleX, Cross, Diamond, DiamondCross,
-                      InvertedTriangle, Marker, Square, SquareCross, SquareX, Triangle, X)
+from .markers import (Asterisk, Circle, CircleCross, CircleX, Cross, Dash,
+                      Diamond, DiamondCross, Hex, InvertedTriangle, Marker,
+                      Square, SquareCross, SquareX, Triangle, X)
 
 # Fool pyflakes
-(Asterisk, Circle, CircleCross, CircleX, Cross, Diamond, DiamondCross,
-InvertedTriangle, Marker, Square, SquareCross, SquareX, Triangle, X)
+(Asterisk, Circle, CircleCross, CircleX, Cross, Dash, Diamond, DiamondCross,
+Hex, InvertedTriangle, Marker, Square, SquareCross, SquareX, Triangle, X)
