@@ -22,7 +22,7 @@ class DataSource(Model):
     '''
 
     selected = Instance(Selection, default=lambda: Selection(), help="""
-    A Selection that indicates selected indices on this DataSource.
+    A Selection that indicates selected indices on this ``DataSource``.
     """)
 
     callback = Instance(Callback, help="""
@@ -41,7 +41,7 @@ class ColumnarDataSource(DataSource):
     '''
 
     selection_policy = Instance(SelectionPolicy, default=lambda: UnionRenderers(), help="""
-    An instance of a SelectionPolicy that determines how selections are set.
+    An instance of a ``SelectionPolicy`` that determines how selections are set.
     """)
 
 class ColumnDataSource(ColumnarDataSource):
@@ -50,7 +50,7 @@ class ColumnDataSource(ColumnarDataSource):
     The ``ColumnDataSource`` is a fundamental data structure of Bokeh. Most
     plots, data tables, etc. will be driven by a ``ColumnDataSource``.
 
-    If the ColumnDataSource initializer is called with a single argument that
+    If the ``ColumnDataSource`` initializer is called with a single argument that
     can be any of the following:
 
     * A Python ``dict`` that maps string names to sequences of values, e.g.
@@ -75,8 +75,8 @@ class ColumnDataSource(ColumnarDataSource):
 
       In this case the CDS will have columns corresponding to the columns of
       the ``DataFrame``. If the ``DataFrame`` columns have multiple levels,
-      they will be flattend using an underscore (e.g. level_0_col_level_1_col).
-      The index of the DataFrame will be flattened to an ``Index`` of tuples
+      they will be flattened using an underscore (e.g. level_0_col_level_1_col).
+      The index of the ``DataFrame`` will be flattened to an ``Index`` of tuples
       if it's a ``MultiIndex``, and then reset using ``reset_index``. The result
       will be a column with the same name if the index was named, or
       level_0_name_level_1_name if it was a named ``MultiIndex``. If the
@@ -93,7 +93,7 @@ class ColumnDataSource(ColumnarDataSource):
       In this case the CDS will have columns corresponding to the result of
       calling ``group.describe()``. The ``describe`` method generates columns
       for statistical measures such as ``mean`` and ``count`` for all the
-      non-grouped orginal columns. The CDS columns are formed by joining
+      non-grouped original columns. The CDS columns are formed by joining
       original column names with the computed measure. For example, if a
       ``DataFrame`` has columns ``'year'`` and ``'mpg'``. Then passing
       ``df.groupby('year')`` to a CDS will result in columns such as
@@ -125,7 +125,7 @@ class ColumnDataSource(ColumnarDataSource):
 
     def __init__(self, *args, **kw):
         ''' If called with a single argument that is a dict or
-        pandas.DataFrame, treat that implicitly as the "data" attribute.
+        ``pandas.DataFrame``, treat that implicitly as the "data" attribute.
 
         '''
         if len(args) == 1 and "data" not in kw:
@@ -153,7 +153,7 @@ class ColumnDataSource(ColumnarDataSource):
 
     @staticmethod
     def _data_from_df(df):
-        ''' Create a ``dict`` of columns from a Pandas DataFrame,
+        ''' Create a ``dict`` of columns from a Pandas ``DataFrame``,
         suitable for creating a ColumnDataSource.
 
         Args:
@@ -190,8 +190,8 @@ class ColumnDataSource(ColumnarDataSource):
 
     @staticmethod
     def _data_from_groupby(group):
-        ''' Create a ``dict`` of columns from a Pandas GroupBy,
-        suitable for creating a ColumnDataSource.
+        ''' Create a ``dict`` of columns from a Pandas ``GroupBy``,
+        suitable for creating a ``ColumnDataSource``.
 
         The data generated is the result of running ``describe``
         on the group.
@@ -207,7 +207,7 @@ class ColumnDataSource(ColumnarDataSource):
 
     @staticmethod
     def _df_index_name(df):
-        ''' Return the Bokeh-appropriate column name for a DataFrame index
+        ''' Return the Bokeh-appropriate column name for a ``DataFrame`` index
 
         If there is no named index, then `"index" is returned.
 
@@ -220,7 +220,7 @@ class ColumnDataSource(ColumnarDataSource):
         is returned.
 
         Args:
-            df (DataFrame) : the DataFrame to find an index name for
+            df (DataFrame) : the ``DataFrame`` to find an index name for
 
         Returns:
             str
@@ -239,8 +239,8 @@ class ColumnDataSource(ColumnarDataSource):
 
     @classmethod
     def from_df(cls, data):
-        ''' Create a ``dict`` of columns from a Pandas DataFrame,
-        suitable for creating a ColumnDataSource.
+        ''' Create a ``dict`` of columns from a Pandas ``DataFrame``,
+        suitable for creating a ``ColumnDataSource``.
 
         Args:
             data (DataFrame) : data to convert
@@ -253,8 +253,8 @@ class ColumnDataSource(ColumnarDataSource):
 
     @classmethod
     def from_groupby(cls, data):
-        ''' Create a ``dict`` of columns from a Pandas GroupBy,
-        suitable for creating a ColumnDataSource.
+        ''' Create a ``dict`` of columns from a Pandas ``GroupBy``,
+        suitable for creating a ``ColumnDataSource``.
 
         The data generated is the result of running ``describe``
         on the group.
@@ -269,7 +269,7 @@ class ColumnDataSource(ColumnarDataSource):
         return cls._data_from_df(data.describe())
 
     def to_df(self):
-        ''' Convert this data source to pandas dataframe.
+        ''' Convert this data source to pandas ``DataFrame``.
 
         Returns:
             DataFrame
@@ -363,7 +363,7 @@ class ColumnDataSource(ColumnarDataSource):
 
     def _stream(self, new_data, rollover=None, setter=None):
         ''' Internal implementation to efficiently update data source columns
-        with new append-only data.   The interal implementation adds the setter
+        with new append-only data. The internal implementation adds the setter
         attribute.  [https://github.com/bokeh/bokeh/issues/6577]
 
         In cases where it is necessary to update data columns in, this method
@@ -477,7 +477,7 @@ class ColumnDataSource(ColumnarDataSource):
         ''' Efficiently update data source columns at specific locations
 
         If it is only necessary to update a small subset of data in a
-        ColumnDataSource, this method can be used to efficiently update only
+        ``ColumnDataSource``, this method can be used to efficiently update only
         the subset, instead of requiring the entire data set to be sent.
 
         This method should be passed a dictionary that maps column names to
@@ -639,7 +639,7 @@ def _check_slice(s):
         raise ValueError("Patch slices must have non-negative (start, stop, step) values, got %s" % s)
 
 class CDSView(Model):
-    ''' A view into a ColumnDataSource that represents a row-wise subset.
+    ''' A view into a ``ColumnDataSource`` that represents a row-wise subset.
 
     '''
 
@@ -648,7 +648,7 @@ class CDSView(Model):
     """)
 
     source = Instance(ColumnarDataSource, help="""
-    The ColumnDataSource associated with this view. Used to determine
+    The ``ColumnDataSource`` associated with this view. Used to determine
     the length of the columns.
     """)
 
@@ -658,8 +658,9 @@ class GeoJSONDataSource(ColumnarDataSource):
     '''
 
     geojson = JSON(help="""
-    GeoJSON that contains features for plotting. Currently GeoJSONDataSource can
-    only process a FeatureCollection or GeometryCollection.
+    GeoJSON that contains features for plotting. Currently
+    ``GeoJSONDataSource`` can only process a ``FeatureCollection`` or
+    ``GeometryCollection``.
     """)
 
 @abstract
@@ -682,7 +683,7 @@ class RemoteSource(ColumnDataSource):
 
 class AjaxDataSource(RemoteSource):
     ''' A data source that can populate columns by making Ajax calls to REST
-    enpoints.
+    endpoints.
 
     The ``AjaxDataSource`` can be especially useful if you want to make a
     standalone document (i.e. not backed by the Bokeh server) that can still
@@ -699,7 +700,7 @@ class AjaxDataSource(RemoteSource):
             'y' : [9, 3, 2, ...]
         }
 
-    Alternatively, if the REST API returns a different format, a CustomJS
+    Alternatively, if the REST API returns a different format, a ``CustomJS``
     callback can be provided to convert the REST response into Bokeh format,
     via the ``adapter`` property of this data source.
 
@@ -708,7 +709,7 @@ class AjaxDataSource(RemoteSource):
     '''
 
     method = Enum('POST', 'GET', help="""
-    Specifiy the the HTTP method to use for the Ajax request (GET or POST)
+    Specify the HTTP method to use for the Ajax request (GET or POST)
     """)
 
     mode = Enum("replace", "append", help="""
@@ -717,15 +718,15 @@ class AjaxDataSource(RemoteSource):
     """)
 
     adapter = Instance(CustomJS, help="""
-    A JavaScript callback to adapt raw JSON responses to Bokeh ColumnDataSource
+    A JavaScript callback to adapt raw JSON responses to Bokeh ``ColumnDataSource``
     format.
 
     If provided, this callback is executes immediately after the JSON data is
-    received, but before apprending or replacing data in the data source. The
-    CustomJS callback will receive the AjaxDataSource as ``cb_obj`` and will
-    receive the raw JSON response as ``cb_data.response``. The callback code
-    should return a ``data`` object suitable for a Bokeh ColumnDataSource (i.e.
-    a mapping of string column names to arrays of data).
+    received, but before appending or replacing data in the data source. The
+    ``CustomJS`` callback will receive the ``AjaxDataSource`` as ``cb_obj`` and
+    will receive the raw JSON response as ``cb_data.response``. The callback
+    code should return a ``data`` object suitable for a Bokeh ``ColumnDataSource``
+    (i.e.  a mapping of string column names to arrays of data).
     """)
 
     max_size = Int(help="""
