@@ -1,11 +1,12 @@
 from __future__ import absolute_import
 import mock
+from datetime import datetime
 
 from bokeh.core.properties import field, value
 from bokeh.core.validation import check_integrity
 from bokeh.models.annotations import (
     Legend, LegendItem, ColorBar, Arrow, BoxAnnotation, Span, LabelSet, Label,
-    Title, Band, Whisker
+    Title, Band, Whisker, Slope
 )
 from bokeh.models import (
     ColumnDataSource, ArrowHead, BasicTicker, BasicTickFormatter, GlyphRenderer
@@ -103,7 +104,8 @@ def test_ColorBar():
         "major_tick_in",
         "major_tick_out",
         "minor_tick_in",
-        "minor_tick_out"],
+        "minor_tick_out",
+        "major_label_overrides"],
         prefix('title_', TEXT),
         prefix('major_label_', TEXT),
         prefix('major_tick_', LINE),
@@ -252,6 +254,11 @@ def test_Label():
         prefix('border_', LINE),
         prefix('background_', FILL))
 
+def test_Label_accepts_datetime_xy():
+    obj = Label(x = datetime(2018,8,7,0,0),
+                y = datetime(2018,8,7,0,0))
+    assert obj.x == 1533600000000.0
+    assert obj.y == 1533600000000.0
 
 def test_LabelSet():
     label_set = LabelSet()
@@ -296,6 +303,25 @@ def test_LabelSet():
         prefix('border_', LINE),
         prefix('background_', FILL))
 
+def test_Slope():
+    slope = Slope()
+    assert slope.plot is None
+    assert slope.gradient is None
+    assert slope.y_intercept is None
+    assert slope.x_range_name == 'default'
+    assert slope.y_range_name == 'default'
+    assert slope.level == 'annotation'
+    check_line_properties(slope, "", 'black', 1.0)
+    check_properties_existence(slope, [
+        "plot",
+        "visible",
+        "gradient",
+        "y_intercept",
+        "x_range_name",
+        "y_range_name",
+        "level",
+    ], LINE)
+
 
 def test_Span():
     line = Span()
@@ -320,12 +346,16 @@ def test_Span():
         "render_mode"
     ], LINE)
 
+def test_Span_accepts_datetime_location():
+    obj = Span(location = datetime(2018,8,7,0,0))
+    assert obj.location == 1533600000000.0
 
 def test_Title():
     title = Title()
     assert title.plot is None
     assert title.level == 'annotation'
     assert title.text is None
+    assert title.vertical_align == 'bottom'
     assert title.align == 'left'
     assert title.offset == 0
     assert title.text_font == 'helvetica'
@@ -340,6 +370,7 @@ def test_Title():
         "visible",
         "level",
         "text",
+        "vertical_align",
         "align",
         "offset",
         "text_font",
@@ -396,7 +427,7 @@ def test_can_add_multiple_glyph_renderers_to_legend_item():
     gr_1 = GlyphRenderer()
     gr_2 = GlyphRenderer()
     legend_item.renderers = [gr_1, gr_2]
-    with mock.patch('bokeh.core.validation.check.logger') as mock_logger:
+    with mock.patch('bokeh.core.validation.check.log') as mock_logger:
         check_integrity([legend_item])
         assert mock_logger.error.call_count == 0
 
@@ -407,7 +438,7 @@ def test_legend_item_with_field_label_and_different_data_sources_raises_a_valida
     gr_2 = GlyphRenderer(data_source=ColumnDataSource(data={'label': [1]}))
     legend_item.label = field('label')
     legend_item.renderers = [gr_1, gr_2]
-    with mock.patch('bokeh.core.validation.check.logger') as mock_logger:
+    with mock.patch('bokeh.core.validation.check.log') as mock_logger:
         check_integrity([legend_item])
         assert mock_logger.error.call_count == 1
 
@@ -418,7 +449,7 @@ def test_legend_item_with_value_label_and_different_data_sources_does_not_raise_
     gr_2 = GlyphRenderer(data_source=ColumnDataSource())
     legend_item.label = value('label')
     legend_item.renderers = [gr_1, gr_2]
-    with mock.patch('bokeh.core.validation.check.logger') as mock_logger:
+    with mock.patch('bokeh.core.validation.check.log') as mock_logger:
         check_integrity([legend_item])
         assert mock_logger.error.call_count == 0
 
@@ -428,6 +459,6 @@ def test_legend_item_with_field_label_raises_error_if_field_not_in_cds():
     gr_1 = GlyphRenderer(data_source=ColumnDataSource())
     legend_item.label = field('label')
     legend_item.renderers = [gr_1]
-    with mock.patch('bokeh.core.validation.check.logger') as mock_logger:
+    with mock.patch('bokeh.core.validation.check.log') as mock_logger:
         check_integrity([legend_item])
         assert mock_logger.error.call_count == 1
