@@ -20,10 +20,9 @@ import pytest ; pytest
 # Standard library imports
 
 # External imports
-import pandas as pd
 
 # Bokeh imports
-from bokeh.util.testing import verify_all
+from bokeh._testing.util.api import verify_all
 
 # Module under test
 #import bokeh.sampledata.us_marriages_divorces as bsu
@@ -43,7 +42,7 @@ ALL = (
 Test___all__ = pytest.mark.sampledata(verify_all("bokeh.sampledata.us_marriages_divorces", ALL))
 
 @pytest.mark.sampledata
-def test_data():
+def test_data(pd):
     import bokeh.sampledata.us_marriages_divorces as bsu
     assert isinstance(bsu.data, pd.DataFrame)
 
