@@ -17,13 +17,25 @@ from tornado.web import StaticFileHandler
 from ..application import Application
 from ..resources import Resources
 from ..settings import settings
+from ..util.dependencies import import_optional
 
-from .application_context import ApplicationContext
+from .contexts import ApplicationContext
 from .connection import ServerConnection
 from .urls import per_app_patterns, toplevel_patterns
 from .views.root_handler import RootHandler
 from .views.static_handler import StaticHandler
 
+# Unfortuntely we can't yet use format_docstring to keep these automatically in sync in
+# the class docstring because Python 2 does not allow setting class.__doc__ (works with
+# Bokeh model classes because they are metaclasses)
+DEFAULT_CHECK_UNUSED_MS                  = 17000
+DEFAULT_KEEP_ALIVE_MS                    = 37000  # heroku, nginx default to 60s timeout, so use less than that
+DEFAULT_MEM_LOG_FREQ_MS                  = 0
+DEFAULT_STATS_LOG_FREQ_MS                = 15000
+DEFAULT_UNUSED_LIFETIME_MS               = 15000
+DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES = 20*1024*1024
+
+
 class BokehTornado(TornadoApplication):
     ''' A Tornado Application used to implement the Bokeh Server.
 
@@ -95,6 +107,12 @@ class BokehTornado(TornadoApplication):
         stats_log_frequency_milliseconds (int, optional) :
             Number of milliseconds between logging stats (default: 15000)
 
+        mem_log_frequency_milliseconds (int, optional) :
+            Number of milliseconds between logging memory information (default: 0)
+
+            Enabling this feature requires the optional dependency ``psutil`` to be
+            installed.
+
         use_index (bool, optional) :
             Whether to generate an index of running apps in the ``RootHandler``
             (default: True)
@@ -107,6 +125,13 @@ class BokehTornado(TornadoApplication):
             If there are multiple Bokeh applications configured, this option
             has no effect.
 
+        websocket_max_message_size_bytes (int, optional):
+            Set the Tornado ``websocket_max_message_size`` value.
+            (default: 20*1024*1024)
+
+            NOTE: This setting has effect ONLY for Tornado>=4.5
+
+    Any additional keyword arguments are passed to ``tornado.web.Application``.
     '''
 
     def __init__(self,
@@ -117,12 +142,15 @@ class BokehTornado(TornadoApplication):
                  secret_key=settings.secret_key_bytes(),
                  sign_sessions=settings.sign_sessions(),
                  generate_session_ids=True,
-                 keep_alive_milliseconds=37000, # heroku, nginx default to 60s timeout, so use less than that
-                 check_unused_sessions_milliseconds=17000,
-                 unused_session_lifetime_milliseconds=15000,
-                 stats_log_frequency_milliseconds=15000,
+                 keep_alive_milliseconds=DEFAULT_KEEP_ALIVE_MS,
+                 check_unused_sessions_milliseconds=DEFAULT_CHECK_UNUSED_MS,
+                 unused_session_lifetime_milliseconds=DEFAULT_UNUSED_LIFETIME_MS,
+                 stats_log_frequency_milliseconds=DEFAULT_STATS_LOG_FREQ_MS,
+                 mem_log_frequency_milliseconds=DEFAULT_MEM_LOG_FREQ_MS,
                  use_index=True,
-                 redirect_root=True):
+                 redirect_root=True,
+                 websocket_max_message_size_bytes=DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES,
+                 **kwargs):
 
         # This will be set when initialize is called
         self._loop = None
@@ -141,21 +169,50 @@ class BokehTornado(TornadoApplication):
         if keep_alive_milliseconds < 0:
             # 0 means "disable"
             raise ValueError("keep_alive_milliseconds must be >= 0")
+        else:
+            if keep_alive_milliseconds == 0:
+                log.info("Keep-alive ping disabled")
+            elif keep_alive_milliseconds != DEFAULT_KEEP_ALIVE_MS:
+                log.info("Keep-alive ping configured every %d milliseconds", keep_alive_milliseconds)
+        self._keep_alive_milliseconds = keep_alive_milliseconds
 
         if check_unused_sessions_milliseconds <= 0:
             raise ValueError("check_unused_sessions_milliseconds must be > 0")
+        elif check_unused_sessions_milliseconds != DEFAULT_CHECK_UNUSED_MS:
+            log.info("Check for unused sessions every %d milliseconds", check_unused_sessions_milliseconds)
+        self._check_unused_sessions_milliseconds = check_unused_sessions_milliseconds
 
         if unused_session_lifetime_milliseconds <= 0:
             raise ValueError("check_unused_sessions_milliseconds must be > 0")
+        elif unused_session_lifetime_milliseconds != DEFAULT_UNUSED_LIFETIME_MS:
+            log.info("Unused sessions last for %d milliseconds", unused_session_lifetime_milliseconds)
+        self._unused_session_lifetime_milliseconds = unused_session_lifetime_milliseconds
 
         if stats_log_frequency_milliseconds <= 0:
             raise ValueError("stats_log_frequency_milliseconds must be > 0")
-
-        self._keep_alive_milliseconds = keep_alive_milliseconds
-        self._check_unused_sessions_milliseconds = check_unused_sessions_milliseconds
-        self._unused_session_lifetime_milliseconds = unused_session_lifetime_milliseconds
+        elif stats_log_frequency_milliseconds != DEFAULT_STATS_LOG_FREQ_MS:
+            log.info("Log statistics every %d milliseconds", stats_log_frequency_milliseconds)
         self._stats_log_frequency_milliseconds = stats_log_frequency_milliseconds
 
+        if mem_log_frequency_milliseconds < 0:
+            # 0 means "disable"
+            raise ValueError("mem_log_frequency_milliseconds must be >= 0")
+        elif mem_log_frequency_milliseconds > 0:
+            if import_optional('psutil') is None:
+                log.warning("Memory logging requested, but is disabled. Optional dependency 'psutil' is missing. "
+                         "Try 'pip install psutil' or 'conda install psutil'")
+                mem_log_frequency_milliseconds = 0
+            elif mem_log_frequency_milliseconds != DEFAULT_MEM_LOG_FREQ_MS:
+                log.info("Log memory usage every %d milliseconds", mem_log_frequency_milliseconds)
+        self._mem_log_frequency_milliseconds = mem_log_frequency_milliseconds
+
+        if websocket_max_message_size_bytes <= 0:
+            raise ValueError("websocket_max_message_size_bytes must be postitive")
+        elif websocket_max_message_size_bytes != DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES:
+            log.info("Torndado websocket_max_message_size set to %d bytes (%0.2f MB)",
+                     websocket_max_message_size_bytes,
+                     websocket_max_message_size_bytes/1024.0**2)
+
         if extra_websocket_origins is None:
             self._websocket_origins = set()
         else:
@@ -218,7 +275,9 @@ class BokehTornado(TornadoApplication):
         for line in pformat(all_patterns, width=60).split("\n"):
             log.debug("  " + line)
 
-        super(BokehTornado, self).__init__(all_patterns)
+        super(BokehTornado, self).__init__(all_patterns,
+                                           websocket_max_message_size=websocket_max_message_size_bytes,
+                                           **kwargs)
 
     def initialize(self, io_loop):
         ''' Start a Bokeh Server Tornado Application on a given Tornado IOLoop.
@@ -234,6 +293,13 @@ class BokehTornado(TornadoApplication):
         self._stats_job = PeriodicCallback(self._log_stats,
                                            self._stats_log_frequency_milliseconds)
 
+        if self._mem_log_frequency_milliseconds > 0:
+            self._mem_job = PeriodicCallback(self._log_mem,
+                                             self._mem_log_frequency_milliseconds)
+        else:
+            self._mem_job = None
+
+
         self._cleanup_job = PeriodicCallback(self._cleanup_sessions,
                                              self._check_unused_sessions_milliseconds)
 
@@ -321,6 +387,8 @@ class BokehTornado(TornadoApplication):
 
         '''
         self._stats_job.start()
+        if self._mem_job is not None:
+            self._mem_job.start()
         self._cleanup_job.start()
         if self._ping_job is not None:
             self._ping_job.start()
@@ -344,6 +412,8 @@ class BokehTornado(TornadoApplication):
             context.run_unload_hook()
 
         self._stats_job.stop()
+        if self._mem_job is not None:
+            self._mem_job.stop()
         self._cleanup_job.stop()
         if self._ping_job is not None:
             self._ping_job.stop()
@@ -404,9 +474,12 @@ class BokehTornado(TornadoApplication):
         raise gen.Return(None)
 
     def _log_stats(self):
+        log.trace("Running stats log job")
+
         if log.getEffectiveLevel() > logging.DEBUG:
             # avoid the work below if we aren't going to log anything
             return
+
         log.debug("[pid %d] %d clients connected", os.getpid(), len(self._clients))
         for app_path, app in self._applications.items():
             sessions = list(app.sessions)
@@ -417,6 +490,25 @@ class BokehTornado(TornadoApplication):
             log.debug("[pid %d]   %s has %d sessions with %d unused",
                       os.getpid(), app_path, len(sessions), unused_count)
 
+    def _log_mem(self):
+        import psutil
+
+        process = psutil.Process(os.getpid())
+        log.info("[pid %d] Memory usage: %0.2f MB (RSS), %0.2f MB (VMS)", os.getpid(), process.memory_info().rss//2**20, process.memory_info().vms//2**20)
+
+        if log.getEffectiveLevel() > logging.DEBUG:
+            # avoid the work below if we aren't going to log anything else
+            return
+
+        import gc
+        from ..document import Document
+        from ..model import Model
+        from .session import ServerSession
+        for name, typ in [('Documents', Document), ('Sessions', ServerSession), ('Models', Model)]:
+            objs = [x for x in gc.get_objects() if isinstance(x, typ)]
+            log.debug("  uncollected %s: %d", name, len(objs))
+
     def _keep_alive(self):
+        log.trace("Running keep alive job")
         for c in self._clients:
             c.send_ping()
